package com.ruoyi.web.controller.custom;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.Result;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.custom.domain.SysGroup;
import com.ruoyi.custom.domain.req.sysgroup.SysGroupEditReq;
import com.ruoyi.custom.domain.req.sysgroup.SysGroupQueryReq;
import com.ruoyi.custom.domain.req.sysgroup.SysGroupSaveReq;
import com.ruoyi.custom.service.SysGroupService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 小组管理Controller
 *
 * @author ruoyi
 * @date 2024-04-23
 */
@Api(tags = "小组管理")
@RestController
@RequestMapping("/custom/group")
public class SysGroupController extends BaseController {
    @Autowired
    private SysGroupService sysGroupService;

    /**
     * 查询小组管理列表
     */
    @ApiOperation("获取小组管理列表")
    @PreAuthorize("@ss.hasPermi('custom:group:list')")
    @GetMapping("/list")
    public Result<List<SysGroup>> list(SysGroupQueryReq sysGroupQueryReq) {
//        startPage();
        List<SysGroup> list = sysGroupService.list(SysGroup.queryBuild(sysGroupQueryReq));
        return Result.success(list);
    }

    /**
     * 导出小组管理列表
     */
    @ApiOperation("导出小组管理列表")
    @PreAuthorize("@ss.hasPermi('custom:group:export')")
    @Log(title = "小组管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, SysGroup sysGroup) {
        List<SysGroup> list = sysGroupService.list(sysGroup);
        ExcelUtil<SysGroup> util = new ExcelUtil<SysGroup>(SysGroup.class);
        util.exportExcel(response, list, "小组管理数据");
    }

    /**
     * 获取小组管理详细信息
     */
    @ApiOperation("获取小组管理详细信息")
    @PreAuthorize("@ss.hasPermi('custom:group:query')")
    @GetMapping(value = "/{groupId}")
    @ApiImplicitParam(name = "groupId", value = "groupId", required = true, dataType = "Long", paramType = "path", dataTypeClass = Long.class)
    public Result<SysGroup> getInfo(@PathVariable("groupId") Long groupId) {
        return Result.success(sysGroupService.getById(groupId));
    }

    /**
     * 新增小组管理
     */
    @PreAuthorize("@ss.hasPermi('custom:group:add')")
    @Log(title = "小组管理", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增小组管理")
    public Result<String> add(@RequestBody SysGroupSaveReq sysGroupSaveReq) {
        return toAjax(sysGroupService.save(SysGroup.saveBuild(sysGroupSaveReq)));
    }

    /**
     * 修改小组管理
     */
    @PreAuthorize("@ss.hasPermi('custom:group:edit')")
    @Log(title = "小组管理", businessType = BusinessType.UPDATE)
    @PutMapping("/{groupId}")
    @ApiOperation("修改小组管理")
    public Result<String> edit(@PathVariable Long groupId, @RequestBody SysGroupEditReq sysGroupEditReq) {
        return toAjax(sysGroupService.updateById(SysGroup.editBuild(groupId, sysGroupEditReq)))
                ;
    }

    /**
     * 删除小组管理
     */
    @PreAuthorize("@ss.hasPermi('custom:group:remove')")
    @Log(title = "小组管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{groupIds}")
    @ApiOperation("删除小组管理")
    @ApiImplicitParam(name = "groupId", value = "groupId", required = true, dataType = "Long", paramType = "path", dataTypeClass = String.class, example = "1,2,3,4")
    public Result<String> remove(@PathVariable List<Long> groupIds) {
        return toAjax(sysGroupService.removeBatchByIds(groupIds));
    }
}
